import {
  useLifeRechargeContext,
  LifePayRateListOutput,
  PhoneParValueOutput,
  PhoneParValueResponse,
} from '../utils';
import { useQuery } from '@tanstack/vue-query';
import { computed } from 'vue';

export function useGetRate() {
  const { blLifeRecharge } = useLifeRechargeContext();

  const { data: lifePayRateList, isLoading } = useQuery({
    queryKey: ['blLifeRecharge/getRate'],
    queryFn: async () => {
      return await blLifeRecharge.services.getRate({ showLoading: false });
    },
    placeholderData: () => [] as LifePayRateListOutput[],
  });

  const lifePayPhoneRate = computed(
    () =>
      lifePayRateList.value.find(
        (x) => x.rateType === blLifeRecharge.constants.LifePayRateTypeEnum.默认话费折扣
      )?.rate ?? 1
  );

  const lifePayElectricRate = computed(
    () =>
      lifePayRateList.value.find(
        (x) => x.rateType === blLifeRecharge.constants.LifePayRateTypeEnum.默认电费折扣
      )?.rate ?? 1
  );

  return {
    lifePayRateList,
    lifePayPhoneRate,
    lifePayElectricRate,
  };
}

export function useGetPhoneParValue() {
  const { blLifeRecharge } = useLifeRechargeContext();

  const { data: phoneParValueList, isLoading } = useQuery({
    queryKey: ['blLifeRecharge/getPhoneParValue'],
    queryFn: async () => {
      return await blLifeRecharge.services.getPhoneParValue({ showLoading: false });
    },
    select(data) {
      return data.phoneParValue ?? [];
    },
    placeholderData: () => ({} as PhoneParValueResponse),
  });

  return {
    phoneParValueList,
  };
}
